==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Visualizzazione grafica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Doppio-click</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Doppio-click per modificare il testo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Doppio-click per modificare il tratteggi</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Doppio-click riferimento di blocco per aprire il blocco</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Destro fare doppio clic per reset</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Blocchi</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Selezionare i riferimenti di blocco insieme con i loro attributi</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Nascondi gli attributi quando riferimenti di blocco sono nascosti</translation>
    </message>
    <message>
        <location line="-85"/>
        <source>Right-Click</source>
        <translation>Pulsante destro del mouse</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Tasto destro del mouse per deselezionare</translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Tasto destro del mouse su un&apos;entità mostra menu contestuale</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Doppio-click per seleziona contorno</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Blocco selezione</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Gamma cursore del mouse</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Cursor range for snap:</source>
        <translation>Gamma cursore del mouse di aggancia:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Cursor range for picking entities:</source>
        <translation>Gamma cursore per scegliere le entità:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Visualizzazione grafica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Doppio-click</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Doppio-click per modificare il testo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Doppio-click per modificare il tratteggi</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Doppio-click riferimento di blocco per aprire il blocco</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Destro fare doppio clic per reset</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Blocchi</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Selezionare i riferimenti di blocco insieme con i loro attributi</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Nascondi gli attributi quando riferimenti di blocco sono nascosti</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Highlight entity within range</source>
        <translation>Evidenziare entità entro il raggio</translation>
    </message>
    <message>
        <source>Keyboard Operations</source>
        <translation type="vanished">Operazioni di tastiera</translation>
    </message>
    <message>
        <source>Angle step for rotating:</source>
        <translation type="vanished">Passo angolare per ruotare:</translation>
    </message>
    <message>
        <location line="-211"/>
        <source>Right-Click</source>
        <translation>Pulsante destro del mouse</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Tasto destro del mouse per deselezionare</translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Tasto destro del mouse su un&apos;entità mostra menu contestuale</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Doppio-click per seleziona contorno</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Blocco selezione</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Gamma cursore del mouse</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Cursor range for snap:</source>
        <translation>Gamma cursore del mouse di aggancia:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Cursor range for picking entities:</source>
        <translation>Gamma cursore per scegliere le entità:</translation>
    </message>
</context>
</TS>
